Learn R Programming

sdtmchecks (version 1.0.0)

check_ds_multdeath_dsstdtc: Check DS with multiple death records with death dates, where death dates do not match

Description

This check looks for patients in DS who have multiple records indicating death, with non-missing mismatching death dates in DSSTDTC.

Usage

check_ds_multdeath_dsstdtc(DS, preproc = identity, ...)

Value

Boolean value for whether the check passed or failed, with 'msg' attribute if the test failed

Arguments

DS

Disposition SDTMv dataset with variables USUBJID, DSDECOD, and DSSTDTC

preproc

An optional company specific preprocessing script

...

Other arguments passed to methods

Author

Kimberly Fernandes

Examples

Run this code

DS_error1 <- data.frame(STUDYID = rep(1, 6),
  USUBJID = c(1, 1, 1, 2, 1,1),
  DSDECOD = c("DEATH", "DEATH", rep("", 2),"DEATH","DEATH"),
  DSSCAT = LETTERS[1:6],
  DSSTDTC = c("", "2016-01-01", "", "", "2016-01-02","2016-01-01"),
  stringsAsFactors = FALSE)

DS_error2 <- data.frame(STUDYID = rep(1, 6),
  USUBJID = c(1, 1, 1, 2, 1,1),
  DSDECOD = c("DEATH", "DEATH", rep("", 2),"DEATH","DEATH"),
  DSSCAT = LETTERS[1:6],
  DSSTDTC = c("", "2016-01", "", "", "2016-01-01","2016-01-01"),
  stringsAsFactors = FALSE)
  
 DS_noerror <- data.frame(STUDYID = rep(1, 6),
                        USUBJID = c(1, 1, 1, 2, 1,1),
                        DSDECOD = c("DEATH", "DEATH", rep("", 2),"DEATH","DEATH"),
                        DSSCAT = LETTERS[1:6],
                        DSSTDTC = c("", "2016-01-01", "", "", "2016-01-01","2016-01-01"),
                        stringsAsFactors = FALSE)

check_ds_multdeath_dsstdtc(DS_error1)
check_ds_multdeath_dsstdtc(DS_error2)
check_ds_multdeath_dsstdtc(DS_noerror)

Run the code above in your browser using DataLab