Learn R Programming

sdtmchecks (version 1.0.0)

check_dv_covid: Check for consistency in COVID-19 DV variables, DVREAS and DVEPRELI

Description

This check looks for inconsistency between DVREAS and DVEPRELI. If DVREAS indicates a COVID-19 related deviation, then DVEPRELI should not be missing and vice versa. This check applies to studies using the Protocol Deviation Management System (PDMS).

Usage

check_dv_covid(DV)

Value

boolean value if check failed or passed with 'msg' attribute if the test failed

Arguments

DV

Protocol Deviations SDTM dataset with variables USUBJID, DVREAS, DVEPRELI

Author

Mij Rahman

See Also

Other COVID: check_ae_aeacn_ds_disctx_covid(), check_ae_aeacnoth_ds_stddisc_covid(), check_dv_ae_aedecod_covid()

Examples

Run this code

DV <- data.frame(
    USUBJID = 1:3,
    DVEPRELI = c("Y","N","Y"),
    DVREAS=c("EPIDEMIC/PANDEMIC INFECTION","EPIDEMIC/PANDEMIC INFECTION",""),
    stringsAsFactors=FALSE
)

check_dv_covid(DV)

Run the code above in your browser using DataLab