Learn R Programming

sdtmchecks (version 1.0.0)

impute_day01: Add day of "01" to dates that are in the format of "yyyy-mm"

Description

Add day of "01" to dates that are in the format of "yyyy-mm"

Usage

impute_day01(dates)

Arguments

Value

string