Learn R Programming

sdtmchecks (version 1.0.0)

is_sas_na: Check if the elements could be of any SAS missing data variant

Description

Missing Data from sas7bdat imported datesets could be imported in different ways we currently check for 'NA', NA, '.', and ''.

Usage

is_sas_na(x)

Value

logical vector

Arguments

x

vector with data

Examples

Run this code
is_sas_na(c(1,2,NA))

is_sas_na(c("a", NA, "NA", ""))

Run the code above in your browser using DataLab