Learn R Programming

sdtmchecks (version 1.0.0)

check_qs_qsstat_qsreasnd: Check to confirm that there is a reason for a questionnaire being marked as not done

Description

This code flags when QSSTAT Completion Status is marked as NOT DONE but QSREASND Reason Not Performed is not populated. Some but not all questionnaires in a study may collect Reason Not Performed information, so there may be instances of false positives in which no data correction is required. While QSREASND is a permissible variable, this scenario will be flagged in P21.

Usage

check_qs_qsstat_qsreasnd(QS)

Value

boolean value if check returns 0 obs, otherwise return subset dataframe.

Arguments

QS

Questionnaire SDTMv dataset with USUBJID, QSCAT, QSDTC, QSSTAT, QSREASND, VISIT (optional) variables

Author

Katie Patel, Bonita Viegas Monteiro, Tom Stone (HackR 2021 Team WeRawesome)

Examples

Run this code

QS <- data.frame(USUBJID = c(1,1,1,2,2,2),
                 QSDTC   = c("2015-06-30", "2015-09-30", "2015-12-30", 
                             "2015-06-30", "2015-09-30", "2015-12-30"),
                 QSCAT   = "A",
                 VISIT  =  c("Week 1", "Week 12", "Week 24", "Week 1", "Week 12", "Week 24"),
                 QSSTAT  = c("Not Done","NOT DONE","not done", rep("",3)),
                 QSREASND = c("Reasons",rep("",5)),
                 stringsAsFactors = FALSE)

 check_qs_qsstat_qsreasnd(QS)

 QS$QSSTAT=NULL

 check_qs_qsstat_qsreasnd(QS)


Run the code above in your browser using DataLab