Learn R Programming

sdtmchecks (version 1.0.0)

check_tu_tuloc_missing: Check for missing TULOC values

Description

This check looks for target lesions with missing TULOC values and returns a data frame. Only applies to assessments by investigator.

Usage

check_tu_tuloc_missing(TU, preproc = identity, ...)

Value

boolean value if check failed or passed with 'msg' attribute if the test failed

Arguments

TU

Tumor Identification SDTM dataset with variables USUBJID, TUDTC, VISIT, TUORRES, TULOC, TUSPID (optional)

preproc

An optional company specific preprocessing script

...

Other arguments passed to methods

Author

Will Harris

Examples

Run this code
TU <- data.frame(
USUBJID = 1:10,
TUDTC = 1:10,
VISIT = "C1D1",
TUORRES = "TARGET",
TULOC = "LIVER",
TUSPID = "FORMNAME-R:19/L:19XXXX",
stringsAsFactors=FALSE
)

check_tu_tuloc_missing(TU)

TU$TULOC[1] = "NA"
TU$TULOC[2] = ""
TU$TULOC[3] = NA

check_tu_tuloc_missing(TU,preproc=roche_derive_rave_row)

TU$TUSPID <- NULL
check_tu_tuloc_missing(TU)


Run the code above in your browser using DataLab